@@ -20,9 +20,10 @@ class GenericSurface(TransformableMixin[_S], Generic[_S]):
             return 'surface_mask2', in_volume, self, output
         return in_volume.create_command(command)
 
-    def adapt_object_mesh(self, n_iterations: int, n_adapt: int, n_adapt_smooth: int) -> _S:
+    def adapt_object_mesh(self, target_points: int, n_iterations: int, n_adapt: int, n_adapt_smooth: int) -> _S:
         def command(output):
-            return 'adapt_object_mesh', self, output, str(n_iterations), str(n_adapt), str(n_adapt_smooth)
+            return 'adapt_object_mesh', self, output, \
+                str(target_points), str(n_iterations), str(n_adapt), str(n_adapt_smooth)
         return self.create_command(command)
 
 
